@@ -10,7 +10,7 @@
 #include "debug.hh"
 
 Lyric_item::Lyric_item(Lyric_req* lreq_l, int voice_count_i)
-    : Text_item(lreq_l,0)
+    : Text_item(lreq_l)
 {
     pos_i_ = -voice_count_i * 4 ;	// 4 fontsize dependant. TODO
     dir_i_ = -1;
