@@ -2,6 +2,7 @@
 #include "input-score.hh"
 #include "input-staff.hh"
 #include "input-music.hh"
+#include "input-register.hh"
 #include "molecule.hh"
 #include "voice-element.hh"
 #include "plist.tcc"
@@ -10,3 +11,4 @@
 IPL_instantiate(Atom);
 IPL_instantiate(Input_staff);
 IPL_instantiate(Input_music);
+IPL_instantiate(Input_register);
